import subprocess
import os
import shutil

def install_package(package_name):
    '''
    # Examp - install package
    ```py
    install_package("pyrogram")
    ```
    '''
    command = f"pip install {package_name}"
    process = subprocess.Popen(command.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    output, error = process.communicate()
    if process.returncode == 0:
        return "{package_name} Installed successfully !"
    else:
        return f"Installation failed with error: {error.decode('utf-8')}"

def uninstall_package(package_name):
    '''
    # Examp - uninstall package
    ```py
    uninstall_package("pyrogram")
    ```
    '''
    command = f"pip uninstall {package_name} -y"
    process = subprocess.Popen(command.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    output, error = process.communicate()
    
    if process.returncode == 0:
        return f"{package_name} uninstalled successfully !"
    else:
        return f"Uninstallation failed with error: {output.decode('utf-8')}"


def run_it(command, input_data=None):
    '''
    # Run  the shell commands

    ```py
    command = "pip uninstall pyrogarm"
    input_data = "Y"
    run_it(command)
    ```
    '''
    process = subprocess.Popen(
        command.split(),
        stdin=subprocess.PIPE,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
    )
    try:
        if input_data is not None:
            process.stdin.write(input_data)
        process.stdin.flush()
        output, error = process.communicate()
        if output:
            Output= "Output: ```\n" + output +"```"
            return Output
        elif error:
            # print("Error:", error)
            Error = "Error: ```\n"+ error + "\n```err"
            return Error
    except Exception as e:
        print(e)


def clone_repo(repo_url, destination:str=None):
    """
    a = clone_repo("https://github.com/heartlog/pasteconnect.git")
    print(a)
    """
    if destination is None:
        subprocess.run(['git', 'clone', repo_url])
    elif destination is not None:
        subprocess.run(['git', 'clone', repo_url, destination])

def delete_repo(repo_path):
    shutil.rmtree(repo_path)

# a = clone_repo("https://github.com/heartlog/pasteconnect.git", ".")
# print(a)

#b = delete_repo("repo")
#print(b)


# def run_simp(cmd):
#     out = subprocess.run(cmd)
#     print(out)

# def run_ssmiip(command):
#     try:
#         subprocess.check_output(command, shell=True)
#         print("Download completed")
#     except subprocess.CalledProcessError as e:
#         print(f"Download failed error code as {e.returncode}")


# print(run_it("pip uninstall pySmartDL", "Y"))


import requests
from .reqsession import reqsession
from bs4 import BeautifulSoup
import json
import os
import asyncio
import math

class FLClient:
    def __init__(self, api_key=None):
        self.api_key = api_key or os.environ['flapi_key']
    def auth(self):
        if not all((self.api_key)):
            raise ValueError("API key must be specified.")
        Api_info = f"https://api.filelions.com/api/account/info?key={self.api_key}"
        try:
            response = reqsession(Api_info)
            response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = json.loads(response.text)
            a_api = json_data["status"]
            if int(a_api) == 200:
                print("You are authorised")
            else:
                print("Unsuccessful ! Check credentials.")
        except Exception as e:
            print(e)

    def upload_video(self, file_path, folder_id=13026):
        Main_API = f"https://api.filelions.com/api/upload/server?key={self.api_key}"
        try:
            response = reqsession(Main_API)
            response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = json.loads(response.text)
            temp_api = json_data["result"]
            print("Temp URL:" + temp_api)
            data = {
                'key': str(self.api_key),
                'fld_id': folder_id
            }
            files = {'file': open(file_path, 'rb')}
            try:
                response = requests.post(temp_api, data=data, files=files)
            except Exception as e:
                print("excp:",e)
            print(response.text)
            response.raise_for_status()
            data_f = json.loads(response.text)
            filecode = data_f["files"][0]["filecode"]
            return filecode
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"


def extract_filecodes_from_json(response_json, base_url="https://filelions.online/d/"):
    try:
        # Parse the JSON string
        if isinstance(response_json, dict):
            data = response_json
        else:
            # Parse the JSON string
            data = json.loads(response_json.text)

        # Extract the "filecode" values and prepend the base_url
        filecodes = [base_url + file['filecode'] for file in data['files']]

        return filecodes
    except json.JSONDecodeError as e:
        print(f"Error parsing JSON: {e}")
        return []


# from heartloglost import FLClient as FL
# FL.auth(api_key)
# FL.upload_video(file_path, folder_id=13026)


import requests
from fake_useragent import UserAgent

def reqsession(url, params=None):
    session = requests.Session()
    session.headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/71.1.2222.33 Safari/537.36",
        "Accept-Encoding": "*",
        "Connection": "keep-alive"
    }
    try:
        response = session.get(url, params=params)
    except Exception as e:
        print(f"An error occurred: {e}")
    finally:
        session.close()
    return response

def postsession(url, data, files=None):
    session = requests.Session()
    session.headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/71.1.2222.33 Safari/537.36",
        "Accept-Encoding": "*",
        "Connection": "keep-alive"
    }
    try:
        response = session.post(url, data=data, files=files)
    except Exception as e:
        print(f"An error occurred: {e}")
    finally:
        session.close()
    return response


def Advreqsession(url, params=None):
    session = requests.Session()
    ua = UserAgent()
    session.headers = {
        "User-Agent": ua.random,
        "Accept-Encoding": "*"
    }
    try:
        response = session.get(url, params=params)
        return response
    except requests.exceptions.RequestException as e:
        print(f"An error occurred: {e}")
    finally:
        session.close()

def Advpostsession(url, data=None, files=None):
    session = requests.Session()
    ua = UserAgent()
    session.headers = {
        "User-Agent": ua.random,
        "Accept-Encoding": "*"
    }
    try:
        response = session.post(url, data=data, files=files)
        return response
    except Exception as e:
        print(f"An error occurred: {e}")
    finally:
        session.close()

# Example usage
# url = "https://example.com"
# response_text = get_response(url)
# print(response_text)

# response = Advreqsession("https://example.com/")
# if response:
#     print(response.text)


import requests
from .reqsession import reqsession, Advreqsession
from bs4 import BeautifulSoup
import json
import os
import asyncio
import math

class GoClient:
    def __init__(self, api_key = None):
        self.api_key = api_key or os.environ['gofiles_key'] or None
    def upload_video(self, file_path: str, folder_id=None):
        '''
        client = GoClient()
        client.upload_video(file_path, folder_id)
        ```json
        {
            "status": "ok",
            "data": {
                "downloadPage": "https://gofile.io/d/Z19n9a",
                "code": "Z19n9a",
                "parentFolder": "3dbc2f87-4c1e-4a81-badc-af004e61a5b4",
                "fileId": "4991e6d7-5217-46ae-af3d-c9174adae924",
                "fileName": "example.mp4",
                "md5": "10c918b1d01aea85864ee65d9e0c2305"
            }
        }
        ```
        '''
        try:
            upload_url = get_go_server()
            data = {}
            if folder_id:
                data["folderId"] = folder_id
            if self.api_key:
                data["token"] = self.api_key
            files = {'file': open(file_path, 'rb')}
            response = requests.post(upload_url, files=files, data=data)
            data_f = json.loads(response.text)
            return data_f
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"

def get_go_server():
    api = "https://api.gofile.io/getServer"
    response = Advreqsession(api)
    json_data = json.loads(response.text)
    server_id = json_data["data"]["server"]
    upload_url = f"https://{server_id}.gofile.io/uploadFile"
    return upload_url
    


import requests
from .reqsession import reqsession, Advreqsession
from bs4 import BeautifulSoup
import json
import os
import asyncio
import math

class STClient:
    def __init__(self, username = None, api_key = None):
        self.username = username or os.environ['streamtape_login']
        self.api_key = api_key or os.environ['streamtape_key']
    def auth(self):
        if not all((self.username, self.api_key)):
            raise ValueError("Username, password, and API key must be specified.")
        Api_info = f"https://api.streamtape.com/account/info?login={self.username}&key={self.api_key}"
        try:
            response = Advreqsession(Api_info)
            # response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = json.loads(response.text)
            a_api = json_data["status"]
            if int(a_api) == 200:
                print("You are authorised")
            else:
                print("Unsuccessful ! Check credentials.")
        except Exception as e:
            print(e)

    def upload_video(self, file_path: str, folder_id=None):
        '''
        client.upload_video(file_path, folder_id)
        '''
        try:
            Main_API = f"https://api.streamtape.com/file/ul?login={self.username}&key={self.api_key}"
            payload = {}
            if folder_id:
                payload["folder"] = folder_id
            response = Advreqsession(Main_API, params=payload)
            # response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = json.loads(response.text)
            temp_api = json_data["result"]["url"]
            print("Temp URL:" + temp_api)
            files = {'file': open(file_path, 'rb')}
            response = requests.post(temp_api, files=files)
            # response.raise_for_status()
            data_f = json.loads(response.text)
            download_link = data_f["result"]["url"]
            print(download_link)
            return download_link
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"

    def tapeimg_url(url):
        try:
            response = Advreqsession(url)
            # response.raise_for_status()
            soup = BeautifulSoup(response.text, 'html.parser')
            og_image_tag = soup.find('meta', {'name': 'og:image'})
            if og_image_tag:
                image_url = og_image_tag['content']
                return image_url
            else:
                return None
        except requests.exceptions.RequestException as e:
            print(f"Error: {e}")
            return None

    def add_remote(self, url: str, folder_id=None, name=None):
        '''
        client.add_remote(url: str, folder_id, name: str)
        '''
        # Main_API = f"https://api.streamtape.com/file/ul?login={self.username}&key={self.api_key}&folder={self.folder_id}"
        if url:
            try:
                Main_API = f"https://api.streamtape.com/remotedl/add?login={self.username}&key={self.api_key}&url={url}"
                payload = {}
                if name:
                    payload["name"] = name
                if folder_id:
                    payload["folder"] = folder_id
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                remote_id = json_data["result"]["id"]
                print("UpID:" + remote_id)
                return remote_id
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please Give Api Key/url/"

    # check out docs\streamtape_gud\remotestatus.md
    def remote_status(self, id):
        '''
        ## Usage
        client.remote_status(remote_id)

        ## Response
        ```json
        {
        "status": 200,
        "msg": "OK",
        "result": {
            "LnvnE51P5gc": {
                "id": "LnvnE51P5gc",
                "remoteurl": "https://vid.me/myvideo123",
                "status": "new",
                "bytes_loaded": null,
                "bytes_total": null,
                "folderid": "LnvnE51P5gc",
                "added": "2019-12-31 23:59:59",
                "last_update": "2019-12-31 23:59:59",
                "extid": false,
                "url": false
            }
        }
        }
        ```
        '''
        if id:
            try:
                Main_API = f"https://api.streamtape.com/remotedl/status?login={self.username}&key={self.api_key}&id={id}"
                payload = {}
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                # print("UpID:" + json_data)
                return json_data
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please Give id and what to get"

# idd = "FVAaYwD_ULM"
# json_res = client.remote_status("FVAaYwD_ULM")
# a = client.remote_status("J4Cx7hXoT1s")
# print(a["status"])
    def file_info(self, file_id):
        '''
        ## Usage 
        client.file_info(file_id)
        ## Response
        ```json
        {
            "status": 200,
            "msg": "OK",
            "result": {
                "wkzYeyVpdyuem9": {
                    "id": "wkzYeyVpdyuem9",
                    "status": 200,
                    "name": "hdidhk.mp4",
                    "size": 197065376,
                    "converted": True,
                    "thumb": "https://thumb.tapecontent.net/thumb/wkzYeyVpdyuem9/kwLzMwjxgofee0.jpg"
                }
            }
        }
        ```json
        ## Failed 
        ```json
        {
            "status": 200,
            "msg": "OK",
            "result": {
                "d7Z7BjY9DDskVVK": {
                    "id": "d7Z7BjY9DDskVVK",
                    "status": 404,
                    "name": False,
                    "size": 0,
                    "converted": False
                }
            }
        }
        ```
        '''
        if file_id:
            try:
                Main_API = f"https://api.streamtape.com/file/info?login={self.username}&key={self.api_key}&file={file_id}"
                payload = {}
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                # print("UpID:" + json_data)
                return json_data
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please Give id and what to get"
        
    def rename_file(self, file_id, name):
        if file_id and name:
            try:
                Main_API = f"https://api.streamtape.com/file/rename?login={self.username}&key={self.api_key}&file={file_id}&name={name}"
                payload = {}
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                return json_data
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please provide id and name."
    def delete_file(self, file_id):
        if file_id:
            try:
                Main_API = f"https://api.streamtape.com/file/delete?login={self.username}&key={self.api_key}&file={file_id}"
                payload = {}
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                return json_data
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please provide id."
    def add_folder(self, name=None, pid=None):
        '''
        Add a folder to the specified parent folder.

        Parameters:
        - name (str): The name of the folder.
        - pid (str): The ID of the parent folder.

        Usage:

        ```py
        client.add_remote(file_id, name, pid)
        ```
        '''
        if name:
            try:
                Main_API = f"https://api.streamtape.com/file/createfolder?login={self.username}&key={self.api_key}&name={name}"
                payload = {}
                if pid:
                    payload["pid"] = pid  # Parent folder
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                FolderId = json_data["result"]["folderid"]
                print(f"Folder {name}:" + FolderId)
                return FolderId
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please Give Api Key/url/"
    def delete_folder(self, folder_id):
        if folder_id:
            try:
                Main_API = f"https://api.streamtape.com/file/deletefolder?login={self.username}&key={self.api_key}&folder={folder_id}"
                payload = {}
                response = Advreqsession(Main_API, params=payload)
                # response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = json.loads(response.text)
                return json_data
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please provide id."
    def list_files(self, parent_folder_id=None):
        try:
            Main_API = f"https://api.streamtape.com/file/listfolder?login={self.username}&key={self.api_key}"
            payload = {}
            if parent_folder_id:
                payload["folder"] = parent_folder_id  # Parent folder
            response = Advreqsession(Main_API, params=payload)
            # response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = json.loads(response.text)
            return json_data
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"


def st_url_id(url):
    """
    st_url_id(url) `url or id`
    """
    if url.startswith("http"):
        return url.split("/", 5)[4]
    else:
        return url

def add_parm(dicti, name, value):
    dicti[f"{name}"] = value

# Example usage:
# client = STClient("your_username", "your_api_key")
# client.auth()
# client.upload_video("path_to_video.mp4", "folder_id")



import os
import ffmpeg

def compress_video(video_full_path: str, output_file_name: str, target_size: int):
    # Reference: https://en.wikipedia.org/wiki/Bit_rate#Encoding_bit_rate
    min_audio_bitrate = 32000
    max_audio_bitrate = 256000

    probe = ffmpeg.probe(video_full_path)
    # Video duration, in s.
    duration = float(probe['format']['duration'])
    # Audio bitrate, in bps.
    audio_bitrate = float(next((s for s in probe['streams'] if s['codec_type'] == 'audio'), None)['bit_rate'])
    # Target total bitrate, in bps.
    target_total_bitrate = (target_size * 1024 * 8) / (1.073741824 * duration)

    # Target audio bitrate, in bps
    if 10 * audio_bitrate > target_total_bitrate:
        audio_bitrate = target_total_bitrate / 10
        if audio_bitrate < min_audio_bitrate < target_total_bitrate:
            audio_bitrate = min_audio_bitrate
        elif audio_bitrate > max_audio_bitrate:
            audio_bitrate = max_audio_bitrate
    # Target video bitrate, in bps.
    video_bitrate = target_total_bitrate - audio_bitrate

    i = ffmpeg.input(video_full_path)
    ffmpeg.output(i, os.devnull,
                  **{'c:v': 'libx264', 'b:v': video_bitrate, 'pass': 1, 'f': 'mp4'}
                  ).overwrite_output().run()
    ffmpeg.output(i, output_file_name,
                  **{'c:v': 'libx264', 'b:v': video_bitrate, 'pass': 2, 'c:a': 'aac', 'b:a': audio_bitrate}
                  ).overwrite_output().run()

# Compress input.mp4 to 280MB and save as output.mp4
# compress_video('/content/vid/Wednesday.S01E01.720p.NF.WEBRip.x264-GalaxyTV.mkv.mp4', '/content/comp/Compressed-Wednesday.S01E01.720p.NF.WEBRip.x264-GalaxyTV.mkv.mp4', 280 * 1000)
# compress_video('input_filr_path.mp4', 'output_file_patb.mp4', 280 * 1000)
# The target size for the compressed video in megabytes (MB). means 280*1000=2800000 KB


from pypdl import Downloader

def pypdl_download(url: str, save_dest: str, num_connections=10):
    dl = Downloader()
    dl.start(url, save_dest, num_connections=num_connections, display=True, multithread=True)

def download(url, save_dest):
    pypdl_download(url, save_dest)

# Example usage:
# url = "https://streamtape.com/get_video?id=d71p7vqm6gSQ0W&expires=1694917360&ip=FHIsDRqOKxSHDN&token=1M3hCTNqKz7w"
# dest = "/content/GoogleColab/lfab.mp4"
# pypdl_download(url, dest)


# make to mount the drive only in google colab
import os
import getpass

code = '''
# make to mount the drive only in google colab
try:
    from google.colab import drive
except ImportError:
    pass
drive.mount('/content/drive')
'''

secret_file_path = '/content/drive/MyDrive/Colab Notebooks/secrets/secrets.txt'

def Google_Secret(secret_file_path=secret_file_path):
    with open(secret_file_path, 'r') as file:
        lines = file.readlines()

    # Loop through the lines and process each one
    for line in lines:
        parts = line.strip().split('=')
        if len(parts) == 2:
            env_name, env_value = parts[0], parts[1]
            OsEnv(env_name, env_value)

# set env variable 
def OsEnv(name, value):
    os.environ[name] = value
    print(f"{name} env is done.")

# [Optional]------
def SetEnv(name):
    secret = getpass.getpass(f"Enter value of {name}: ")
    os.environ[name] = secret

def getpSecret():
    SetEnv("api_id")
    SetEnv("api_hash")
    SetEnv("bot_token")
# ------
def SetPass(inp, secr_file=secret_file_path):
    if inp == "A":
        try:
            exec(code)
        except:
            pass
        Google_Secret(secr_file)
    elif inp == "B":
        getpSecret()

# SetPass("A")


import os
import asyncio
import math
import re
import shutil

async def progress(current, total):
    prog = "Progress: " + f"{current * 100 / total:.1f}%"
    print(f"{current * 100 / total:.1f}%")
    return prog

# Function get size
def get_file_size(file_path):
    size_bytes = os.path.getsize(file_path)
    size = humanbytes(size_bytes)
    print(size)
    return size

def humanbytes(size_bytes):
    '''
    ## Turn bytes to human redable size
    print(humanbytes(4855989))
    >>> 4.63 MB
    '''
    if size_bytes == 0:
        return "0B"
    size_name = ("B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB")
    i = int(math.floor(math.log(size_bytes, 1024)))
    p = math.pow(1024, i)
    s = round(size_bytes / p, 2)
    return "%s %s" % (s, size_name[i])

def list_files(directory_path: str):
    """
    ## list all files in the given directory
    ```py
    list_files("Googlecolb")
    ```
    """
    try:
        # Get a list of all files in the specified directory
        files = os.listdir(directory_path)

        # Print the names of all files
        for file_name in files:
            print(file_name)
    except OSError as e:
        print(f"Error: {e}")

# Replace 'directory_path' with the path to the directory you want to list files from
# directory_path = "/content/torr/Wednesday.S01.COMPLETE.720p.NF.WEBRip.x264-GalaxyTV[TGx]"
# list_files(directory_path)

def delete_files(directory_path):
    """
    delete_files_in_dir(dir_path)
    """
    try:
        for filename in os.listdir(directory_path):
            file_path = os.path.join(directory_path, filename)
            if os.path.isfile(file_path):
                os.remove(file_path)
        return f"Deleted files in {directory_path}"
    except Exception as e:
        return e

def delete_files_in_dir(directory):
    try:
        for filename in os.listdir(directory):
            file_path = os.path.join(directory, filename)
            if os.path.isfile(file_path):
                os.remove(file_path)
        print("Files deleted successfully.")
    except Exception as e:
        print(f"An error occurred: {e}")

def copy_file(source_path, destination_path):
    """
    source_file = 'path/to/source/file.txt'
    destination_file = 'path/to/destination/file.txt'
    copy_file(source_file, destination_file)
    """
    try:
        shutil.copy(source_path, destination_path)
        return f"File copied from {source_path} to {destination_path}"
    except IOError as e:
        return f"An error occurred: {e}"

def youtube_url_id(url):
    """
    ## list all files in the given directory
    ```py
    YT_URL = "https://youtube.com/watch?v=yZv2daTWRZU&feature=em-uploademail"
    youtube_url_id(YT_URL)
    >>> yZv2daTWRZU
    ```
    """
    regex = r"^((https?://(?:www\.)?(?:m\.)?youtube\.com))/((?:oembed\?url=https?%3A//(?:www\.)youtube.com/watch\?(?:v%3D)(?P<video_id_1>[\w\-]{10,20})&format=json)|(?:attribution_link\?a=.*watch(?:%3Fv%3D|%3Fv%3D)(?P<video_id_2>[\w\-]{10,20}))(?:%26feature.*))|(https?:)?(\/\/)?((www\.|m\.)?youtube(-nocookie)?\.com\/((watch)?\?(app=desktop&)?(feature=\w*&)?v=|embed\/|v\/|e\/)|youtu\.be\/)(?P<video_id_3>[\w\-]{10,20})"
    match = re.match(regex, url, re.IGNORECASE)
    if match:
        return (
            match.group("video_id_1")
            or match.group("video_id_2")
            or match.group("video_id_3")
        )
    else:
        return None
# url = "https://youtube.com/watch?v=yZv2daTWRZU&feature=em-uploademail"
# get_by_url(url) >> yZv2daTWRZU


from .streamtape import *
from .getpasscolab import *
from .fileslion import *
from .compressvideo import *
from .streamtapedl import *
from .pypdl import *
from .ulty import *
from .torrent import *
from .GoogleTTS import *
from .reqsession import *
from .shell import *
from .gofiles import *
from .pixeldrain import *


import requests
from .reqsession import reqsession, Advreqsession
from bs4 import BeautifulSoup
import json
import os
import base64
import asyncio
import math

# = None

class PixClient:
    def __init__(self, api_key = None):
        self.api_key = api_key or os.environ['gofiles_key'] or None
    def upload(self, file_path: str=None, name :str=None, anon=True):
        '''
        client = GoClient()
        client.upload(file_path, folder_id)
        ```json
        {
        "success": true,
        "id": "abc123" // ID of the newly uploaded file
        }
        ```
        '''
        try:
            upload_url = "https://pixeldrain.com/api/file/"
            data = {}
            data["anonymous"]=True if anon is True else False
            if name:
                data["name"] = name
            if self.api_key:
                data["Authorization"] = "Basic " + base64.b64encode(f":{self.api_key}".encode()).decode()
            files = {'file': open(file_path, 'rb')}
            response = requests.post(upload_url, files=files, data=data)
            data_f = json.loads(response.text)
            return data_f
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"

